@@ -154,10 +154,9 @@ def setup(settings_path=None, **settings_patches):
 
     # Make beanstalk access ssh
     local('sed -i.bak -e "/^AllowGroups wheel$/cAllowGroups wheel beanstalk" /etc/ssh/sshd_config')
-    local('/etc/init.d/sshd restart')
 
     # Apache conf
-    local('touch %s' % apache_conf_path())
+    local('echo "# Beanstalk Apache conf" > %s' % apache_conf_path())
     local('chown beanstalk:beanstalk %s' % apache_conf_path())
 
     # Create homebase
@@ -170,6 +169,9 @@ def setup(settings_path=None, **settings_patches):
     local('chmod o+rx %s' % beanstalk_stack_base)
     local('chown -R beanstalk:beanstalk %s' % beanstalk_stack_base)
 
+    local('/etc/init.d/sshd restart')
+    local('/etc/init.d/httpd reload')
+
 
 @task
 @beanstalk_role('server')
@@ -211,35 +213,35 @@ def create_app(project_name, settings_path=None, **settings_patches):
             local('git add .gitignore')
             local('git commit -m "Init commit"')
 
-    # Add to pool
+    # Apps pool
+    with open(apps_pool_path(), 'r') as f:
+        apps_pool = json.loads(f.read())
+
+    # Get uwsgi port
     uwsgi_port = None
-
-    def editor(apps_pool):
-        # Get uwsgi port
-        global uwsgi_port
-        if project_name in apps_pool:
-            uwsgi_port = apps_pool[project_name]['uwsgi']['port']
+    if project_name in apps_pool:
+        uwsgi_port = apps_pool[project_name]['uwsgi']['port']
+    else:
+        app_ports = [app['uwsgi']['port'] for name, app in apps_pool.items()]
+        if len(app_ports) == 0:
+            uwsgi_port = 50000  # >= 49152
         else:
-            app_ports = [app['uwsgi']['port'] for name, app in apps_pool.items()]
-            if len(app_ports) == 0:
-                uwsgi_port = 50000  # >= 49152
-            else:
-                try_times = 1
-                while try_times <= 10:
-                    try:
-                        uwsgi_port = max(app_ports) + try_times
-                        s = socket.socket()
-                        s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-                        s.bind(('localhost', uwsgi_port))
-                        break
-                    except socket.error:
-                        uwsgi_port = None
-                        try_times += 1
-        if uwsgi_port is None:
-            abort('No available port')
+            try_times = 1
+            while try_times <= 10:
+                try:
+                    uwsgi_port = max(app_ports) + try_times
+                    s = socket.socket()
+                    s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+                    s.bind(('localhost', uwsgi_port))
+                    break
+                except socket.error:
+                    uwsgi_port = None
+                    try_times += 1
+    if uwsgi_port is None:
+        abort('No available port')
 
-        # Add it
-        apps_pool[project_name] = {
+    def editor(pool):
+        pool[project_name] = {
             'path': {
                 'base': project_base,
                 'source': project_source,
@@ -250,12 +252,11 @@ def create_app(project_name, settings_path=None, **settings_patches):
                 'port': uwsgi_port,
             },
         }
-
-        return apps_pool
+        return pool
     print section_title('Add app to app_pool')
     edit_file(apps_pool_path(), editor=editor)
 
-    print section_title('Add apache to apache httpd')
+    print section_title('Add to apache httpd')
     with open(apache_conf_path(), 'r') as f:
         apache_conf = f.read()
     if not '# %s' % project_name in apache_conf:
@@ -269,11 +270,8 @@ def create_app(project_name, settings_path=None, **settings_patches):
             '#' + '-' * 20,
             ' ',
         ]
-        sed_commands = []
-        for command in commands:
-            sed_commands.append('$a\\\n%s' % command)
-        sed_command = ';'.join(sed_commands)
-        local('sed -i.bak -e \'%s\' %s && rm -rf %s.bak' % (sed_command, apache_conf_path(), apache_conf_path()))
+        sed_command = '\\\n'.join(commands)
+        local('sed -i.bak -e \'$a\\%s\' %s && rm -rf %s.bak' % (sed_command, apache_conf_path(), apache_conf_path()))
 
 
 @task
